"""
Brainfuck Tools
~~~~~~~~~~~~~~~

A brainfuck toolbox for python.

:copyright: (c) 2021 BobDotCom
:license: MIT, see LICENSE for more details.

"""

from .core import *
from .enums import *
from .compiler import *
from .encoder import *
from .tools import *

__title__ = 'bftools'
__author__ = 'BobDotCom'
__license__ = 'MIT'
__copyright__ = 'Copyright 2021 BobDotCom'
__version__ = '0.1.0'
